@@ -1,6 +1,13 @@
 """Utility functions for data structure handling."""
 
-__all__ = ["ParameterList", "AzElData", "ParameterMapping", "ValueRange", "toCamelCase"]
+__all__ = [
+    "ParameterList",
+    "AzElData",
+    "ParameterMapping",
+    "ValueRange",
+    "toCamelCase",
+    "to_snake_case",
+]
 
 import re
 from dataclasses import dataclass
@@ -42,7 +49,7 @@ class ParameterList(list):
         super().__init__(value)
 
     @classmethod
-    def new(cls, length: int, initvalue: Any = np.nan) -> "ParameterList":
+    def new(cls, length: int, initvalue: Any = float("nan")) -> "ParameterList":
         """Create new ParameterList instance filled with initial value.
 
         Parameters
@@ -234,7 +241,7 @@ class ValueRange(Generic[T]):
 
         """
         try:
-            return self.upper - self.lower
+            return self.upper - self.lower  # type: ignore
         except TypeError:
             return None
 
@@ -317,3 +324,9 @@ def toCamelCase(
             lambda mo: mo.group(1).lower() + mo.group(2),
             PascalCase,
         )
+    raise ValueError(f"Unknown kind: {kind}")
+
+
+def to_snake_case(data: str) -> str:
+    ret = re.sub(r"(?!^)([A-Z])([a-z]+)", r"_\1\2", data).lower()
+    return re.sub(r"\s", "_", ret)
